hssm

package
v0.0.0-...-2a0b7f0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExecuteTemplate

func ExecuteTemplate(sourceFilePath string, funcMap template.FuncMap, verbose bool) (string, error)

ExecuteTemplate loads a template file, executes is against a given function map and writes the output

func GetFuncMap

func GetFuncMap(profile string, prefix string, clean bool, tagCleaned string) template.FuncMap

GetFuncMap builds the relevant function map to helm_ssm

func GetSSMParameter

func GetSSMParameter(svc ssmiface.SSMAPI, name string, defaultValue *string, decrypt bool) (*string, error)

GetSSMParameter gets a parameter from the AWS Simple Systems Manager service.

func WriteFile

func WriteFile(targetFilePath string, content string) error

WriteFile dumps a given content on the file with path `targetFilePath`.

func WriteFileD

func WriteFileD(fileName string, targetDir string, content string) error

WriteFileD dumps a given content on the file with path `targetDir/fileName`.

Types

This section is empty.

Jump to